@@ -1,17 +1,17 @@
-package Log::Any::Adapter::LinuxJournal 0.172761;
+package Log::Any::Adapter::LinuxJournal 0.172762;
 
 # ABSTRACT: Log::Any adapter for the systemd journal on Linux
 
 use v5.12;
 use warnings;
 
-use Linux::Systemd::Journal::Write;
+use Linux::Systemd::Journal::Write 1.172760;
 use Log::Any::Adapter::Util '1.700';
 use base 'Log::Any::Adapter::Base';
 
 sub init {
     my $self = shift;
-    $self->{jnl} = Linux::Systemd::Journal::Write->new(@_);
+    $self->{jnl} = Linux::Systemd::Journal::Write->new(@_, caller_level => 2);
     return;
 }
 
@@ -67,7 +67,7 @@ Log::Any::Adapter::LinuxJournal - Log::Any adapter for the systemd journal on Li
 
 =head1 VERSION
 
-version 0.172761
+version 0.172762
 
 =head1 SYNOPSIS
 
